"use strict";

exports.__esModule = true;
exports.default = void 0;

var _electron = _interopRequireDefault(require("electron"));

var _react = require("react");

var _reactNativeWeb = require("react-native-web");

var _warning = _interopRequireDefault(require("warning"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class WebView extends _react.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "state", {
      viewState: 'IDLE',
      lastErrorEvent: null // flowlint-next-line deprecated-type:off

    });

    _defineProperty(this, "webviewRef", (0, _react.createRef)());

    _defineProperty(this, "onDomReady", () => {
      if (this.webviewRef.current != null && this.props.injectedJavaScript != null) {
        this.webviewRef.current.executeJavaScript(this.props.injectedJavaScript);
      }
    });

    _defineProperty(this, "onDidFailLoad", event => {
      if (this.props.onError) {
        this.props.onError(event);
      }

      if (this.props.onLoadEnd) {
        this.props.onLoadEnd(event);
      }

      this.setState({
        lastErrorEvent: event,
        viewState: 'ERROR'
      });
    });

    _defineProperty(this, "onDidFinishLoad", event => {
      if (this.props.onLoad) {
        this.props.onLoad(event);
      }

      if (this.props.onLoadEnd) {
        this.props.onLoadEnd(event);
      }

      this.setState({
        viewState: 'IDLE'
      });
    });

    _defineProperty(this, "onDidStartLoading", event => {
      if (this.props.onLoadStart) {
        this.props.onLoadStart(event);
      }

      this.setState({
        viewState: 'LOADING'
      });
    });

    _defineProperty(this, "onWillNavigate", e => {
      if (this.props.onNavigationStateChange) {
        this.props.onNavigationStateChange({
          loading: true,
          url: e.url
        });
      }
    });

    _defineProperty(this, "onDidNavigate", e => {
      if (this.props.onNavigationStateChange) {
        this.props.onNavigationStateChange({
          loading: false,
          url: e.url
        });
      }
    });

    _defineProperty(this, "onIPCMessage", e => {
      if (e.channel === 'postMessage' && this.props.onMessage) {
        const msg = new Event('message');
        msg.nativeEvent = e;
        msg.nativeEvent.data = e.args[0];
        this.props.onMessage(msg);
      }
    });

    _defineProperty(this, "postMessage", message => {
      if (this.props.onMessage) {
        this.webviewRef.current && this.webviewRef.current.send('postMessage', message);
      } else {
        (0, _warning.default)(false, 'Cannot use postMessage() without setting the onMessage() handler');
      }
    });
  }

  componentDidMount() {
    const webview = this.webviewRef.current;

    if (webview != null) {
      webview.addEventListener('dom-ready', this.onDomReady);
      webview.addEventListener('did-fail-load', this.onDidFailLoad);
      webview.addEventListener('did-finish-load', this.onDidFinishLoad);
      webview.addEventListener('did-start-loading', this.onDidStartLoading);

      if (this.props.onMessage) {
        webview.addEventListener('ipc-message', this.onIPCMessage);
      }

      if (this.props.onNavigationStateChange) {
        webview.addEventListener('will-navigate', this.onWillNavigate);
        webview.addEventListener('did-navigate', this.onDidNavigate);
      }
    }
  }

  componentDidUpdate(prevProps) {
    const webview = this.webviewRef.current;

    if (webview != null) {
      if (prevProps.onMessage) {
        if (!this.props.onMessage) {
          webview.removeEventListener('ipc-message', this.onIPCMessage);
        }
      } else if (this.props.onMessage) {
        webview.addEventListener('ipc-message', this.onIPCMessage);
      }

      if (prevProps.onNavigationStateChange) {
        if (!this.props.onNavigationStateChange) {
          webview.removeEventListener('will-navigate', this.onWillNavigate);
          webview.removeEventListener('did-navigate', this.onDidNavigate);
        }
      } else if (this.props.onNavigationStateChange) {
        webview.addEventListener('will-navigate', this.onWillNavigate);
        webview.addEventListener('did-navigate', this.onDidNavigate);
      }
    }
  }

  componentWillUnmount() {
    const webview = this.webviewRef.current;

    if (webview != null) {
      webview.removeEventListener('dom-ready', this.onDomReady);
      webview.removeEventListener('did-fail-load', this.onDidFailLoad);
      webview.removeEventListener('did-finish-load', this.onDidFinishLoad);
      webview.removeEventListener('did-start-loading', this.onDidStartLoading);

      if (this.props.onMessage) {
        webview.removeEventListener('ipc-message', this.onIPCMessage);
      }

      if (this.props.onNavigationStateChange) {
        webview.removeEventListener('will-navigate', this.onWillNavigate);
        webview.removeEventListener('did-navigate', this.onDidNavigate);
      }
    }
  }

  render() {
    const {
      injectedJavaScript: _ijs,
      onError: _oe,
      onLoad: _ol,
      onLoadStart: _ols,
      onLoadEnd: _ole,
      onMessage,
      onNavigationStateChange: _onsc,
      source,
      ...props
    } = this.props;
    const extraProps = {};

    if (onMessage) {
      extraProps.preload = _electron.default.remote.require('path').resolve(__dirname, 'WebView.preload');
    }

    let src;

    if (source.uri != null) {
      src = source.uri;
    } else if (typeof source.html === 'string') {
      src = `data:text/html,${source.html}`;
    } // flowlint-next-line inexact-spread:off


    return (0, _reactNativeWeb.createElement)('webview', {
      ref: this.webviewRef,
      src,
      ...extraProps,
      ...props
    });
  }

}

exports.default = WebView;